==> apache-camel-2.22.2-src.zip: apache-camel-2.22.2/components/camel-spring-ws/src/main/java/org/apache/camel/component/spring/ws/SpringWebserviceMessage.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.spring.ws;

import org.apache.camel.CamelContext;
import org.apache.camel.impl.DefaultMessage;
import org.springframework.ws.WebServiceMessage;

public class SpringWebserviceMessage extends DefaultMessage {
    private WebServiceMessage webServiceMessage;

    public SpringWebserviceMessage(CamelContext camelContext, WebServiceMessage webServiceMessage) {
        super(camelContext);
        this.webServiceMessage = webServiceMessage;
    }

    @Override
    protected Object createBody() {
        if (webServiceMessage != null) {
            return webServiceMessage.getPayloadSource();
        }
        return null;
    }

    public WebServiceMessage getWebServiceMessage() {
        return webServiceMessage;
    }

    public void setWebServiceMessage(WebServiceMessage webServiceMessage) {
        this.webServiceMessage = webServiceMessage;
    }

    @Override
    public DefaultMessage newInstance() {
        return new SpringWebserviceMessage(getCamelContext(), webServiceMessage);
    }

    @Override
    public String toString() {
        return "SpringWebserviceMessage[" + webServiceMessage + "]";
    }
}

==> apache-camel-4.8.9-src.zip: apache-camel-4.8.9/components/camel-spring-ws/src/main/java/org/apache/camel/component/spring/ws/SpringWebserviceMessage.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.spring.ws;

import org.apache.camel.CamelContext;
import org.apache.camel.support.DefaultMessage;
import org.springframework.ws.WebServiceMessage;

public class SpringWebserviceMessage extends DefaultMessage {
    private WebServiceMessage webServiceMessage;

    public SpringWebserviceMessage(CamelContext camelContext, WebServiceMessage webServiceMessage) {
        super(camelContext);
        this.webServiceMessage = webServiceMessage;
    }

    @Override
    public void reset() {
        super.reset();
        webServiceMessage = null;
    }

    @Override
    protected Object createBody() {
        if (webServiceMessage != null) {
            return webServiceMessage.getPayloadSource();
        }
        return null;
    }

    public WebServiceMessage getWebServiceMessage() {
        return webServiceMessage;
    }

    public void setWebServiceMessage(WebServiceMessage webServiceMessage) {
        this.webServiceMessage = webServiceMessage;
    }

    @Override
    public DefaultMessage newInstance() {
        return new SpringWebserviceMessage(getCamelContext(), webServiceMessage);
    }

    @Override
    public String toString() {
        return "SpringWebserviceMessage[" + webServiceMessage + "]";
    }
}
